==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/StorageAccountStaticWebsiteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin

import com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Enables the static website feature of a storage account.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:storage:StorageAccountStaticWebsite myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/staticWebsite
 * ```
 * @property accountName The name of the storage account within the specified resource group.
 * @property error404Document The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
 * @property indexDocument The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
 * @property resourceGroupName The name of the resource group within the user's subscription. The name is case insensitive.
 */
public data class StorageAccountStaticWebsiteArgs(
    public val accountName: Output<String>? = null,
    public val error404Document: Output<String>? = null,
    public val indexDocument: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs =
        com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .error404Document(error404Document?.applyValue({ args0 -> args0 }))
            .indexDocument(indexDocument?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageAccountStaticWebsiteArgs].
 */
@PulumiTagMarker
public class StorageAccountStaticWebsiteArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var error404Document: Output<String>? = null

    private var indexDocument: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The name of the storage account within the specified resource group.
     */
    @JvmName("svnhuisjaenujcqe")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
     */
    @JvmName("joofnbbcgefaxppb")
    public suspend fun error404Document(`value`: Output<String>) {
        this.error404Document = value
    }

    /**
     * @param value The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
     */
    @JvmName("ofwckgldmtbtaljc")
    public suspend fun indexDocument(`value`: Output<String>) {
        this.indexDocument = value
    }

    /**
     * @param value The name of the resource group within the user's subscription. The name is case insensitive.
     */
    @JvmName("jmmkdbuexyoqeoic")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the storage account within the specified resource group.
     */
    @JvmName("evhkvbqxlorcadey")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
     */
    @JvmName("bgunwhqsvfhgmqpj")
    public suspend fun error404Document(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.error404Document = mapped
    }

    /**
     * @param value The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
     */
    @JvmName("cjcmomwqeyiijwcj")
    public suspend fun indexDocument(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexDocument = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription. The name is case insensitive.
     */
    @JvmName("arsqmwnvmtsnrwhv")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): StorageAccountStaticWebsiteArgs = StorageAccountStaticWebsiteArgs(
        accountName = accountName,
        error404Document = error404Document,
        indexDocument = indexDocument,
        resourceGroupName = resourceGroupName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/StorageAccountStaticWebsiteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin

import com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Enables the static website feature of a storage account.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:storage:StorageAccountStaticWebsite myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/staticWebsite
 * ```
 * @property accountName The name of the storage account within the specified resource group.
 * @property error404Document The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
 * @property indexDocument The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
 * @property resourceGroupName The name of the resource group within the user's subscription. The name is case insensitive.
 */
public data class StorageAccountStaticWebsiteArgs(
    public val accountName: Output<String>? = null,
    public val error404Document: Output<String>? = null,
    public val indexDocument: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs =
        com.pulumi.azurenative.storage.StorageAccountStaticWebsiteArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .error404Document(error404Document?.applyValue({ args0 -> args0 }))
            .indexDocument(indexDocument?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageAccountStaticWebsiteArgs].
 */
@PulumiTagMarker
public class StorageAccountStaticWebsiteArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var error404Document: Output<String>? = null

    private var indexDocument: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The name of the storage account within the specified resource group.
     */
    @JvmName("whxmomkgaibefmst")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
     */
    @JvmName("figeitcbwvpgtddi")
    public suspend fun error404Document(`value`: Output<String>) {
        this.error404Document = value
    }

    /**
     * @param value The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
     */
    @JvmName("owokrkbrmypmrglg")
    public suspend fun indexDocument(`value`: Output<String>) {
        this.indexDocument = value
    }

    /**
     * @param value The name of the resource group within the user's subscription. The name is case insensitive.
     */
    @JvmName("dttrawhjrblukaka")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the storage account within the specified resource group.
     */
    @JvmName("tyuilubqcqwtdrnb")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value The absolute path to a custom webpage that should be used when a request is made which does not correspond to an existing file.
     */
    @JvmName("yceehrqqwyabuipx")
    public suspend fun error404Document(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.error404Document = mapped
    }

    /**
     * @param value The webpage that Azure Storage serves for requests to the root of a website or any sub-folder. For example, 'index.html'. The value is case-sensitive.
     */
    @JvmName("ulxqhdtoyoifgigr")
    public suspend fun indexDocument(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexDocument = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription. The name is case insensitive.
     */
    @JvmName("tcpphggdqvqiaasv")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): StorageAccountStaticWebsiteArgs = StorageAccountStaticWebsiteArgs(
        accountName = accountName,
        error404Document = error404Document,
        indexDocument = indexDocument,
        resourceGroupName = resourceGroupName,
    )
}
